==> moe430b.db_2.2.5.tar.gz: moe430b.db/man/moe430b_dbconn.Rd <==
\name{moe430b_dbconn}

\alias{moe430b_dbconn}
\alias{moe430b_dbfile}
\alias{moe430b_dbschema}
\alias{moe430b_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  moe430b_dbconn()
  moe430b_dbfile()
  moe430b_dbschema(file="", show.indices=FALSE)
  moe430b_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{moe430b_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{moe430b_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{moe430b_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{moe430b_dbschema} prints the schema definition of the
  package annotation DB.

  \code{moe430b_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{moe430b_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{moe430b_dbfile}: a character string with the path to the
  package annotation DB.

  \code{moe430b_dbschema}: none (invisible \code{NULL}).

  \code{moe430b_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(moe430b_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by moe430b_dbconn() was created with:
  dbConnect(SQLite(), dbname=moe430b_dbfile(), cache_size=64000, synchronous=0)

  moe430b_dbschema()

  moe430b_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> moe430b.db_3.0.0.tar.gz: moe430b.db/man/moe430b_dbconn.Rd <==

\name{moe430b_dbconn}

\alias{moe430b_dbconn}
\alias{moe430b_dbfile}
\alias{moe430b_dbschema}
\alias{moe430b_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  moe430b_dbconn()
  moe430b_dbfile()
  moe430b_dbschema(file="", show.indices=FALSE)
  moe430b_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{moe430b_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{moe430b_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{moe430b_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{moe430b_dbschema} prints the schema definition of the
  package annotation DB.

  \code{moe430b_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{moe430b_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{moe430b_dbfile}: a character string with the path to the
  package annotation DB.

  \code{moe430b_dbschema}: none (invisible \code{NULL}).

  \code{moe430b_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(moe430b_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by moe430b_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=moe430b_dbfile(), cache_size=64000,
  synchronous=0)

  moe430b_dbschema()

  moe430b_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
